import examplecurves
from arithmeticmeancurve import ArithmeticMeanCurve

sample_curves = examplecurves.Static.create(
    family_name="nonlinear0", predefined_offset=1
)
a_mean_curve = ArithmeticMeanCurve(sample_curves)

import matplotlib.pyplot as plt

# Setup figure
fig = plt.figure(figsize=(10, 5), dpi=96)
gspec = fig.add_gridspec(1, 1)
axis = fig.add_subplot(gspec[:, :])

# Plot
for index, (label, curve) in enumerate(a_mean_curve.family_of_curves.iteritems()):
    current_label = "Sample curve {}".format(index)
    axis.plot(curve, marker="o", markersize=3, label=current_label)
axis.plot(a_mean_curve.mean_curve, "--ko", markersize=5, label="Arithmetic mean curve")
axis.plot(a_mean_curve.scatter_curve, ":k", label="Scatter curve")

# Finishing touch
axis.legend()
axis.set_xlim(right=0.3)
axis.set_ylim(top=3.0)
plt.tight_layout()
plt.show()



import examplecurves
from arithmeticmeancurve import ArithmeticMeanCurve, MeanCurvePlotter

sample_curves = examplecurves.Static.create(
    family_name="nonlinear0", predefined_offset=1
)
a_mean_curve = ArithmeticMeanCurve(sample_curves)

import matplotlib.pyplot as plt
# Setup figure
fig = plt.figure(figsize=(10, 5), dpi=96)
gspec = fig.add_gridspec(1, 1)

upper_axis = fig.add_subplot(gspec[:, :])
MeanCurvePlotter.plot_default(axis=upper_axis, a_mean_curve=a_mean_curve)

# Finishing touch
plt.tight_layout()
plt.legend()
plt.show()


import examplecurves
from arithmeticmeancurve import FrozenStdExtrapolation, VisualIterationTester, \
    MeanCurvePlotter, ArithmeticMeanCurve

test_family_name = "VerticalLinear1"
sample_curves = examplecurves.Static.create(family_name=test_family_name)

extrapolates = FrozenStdExtrapolation(use_previous_iteration=False, target_threshold=0.0001)
VisualIterationTester.plot_extrapolation_test(
    curves=sample_curves,
    extrapolates=extrapolates,
)

extrapolates = FrozenStdExtrapolation(use_previous_iteration=False, target_threshold=0.0001)
a_mean_curve = ArithmeticMeanCurve(sample_curves, method=extrapolates)
MeanCurvePlotter.test_plot_mean_curve(
    a_mean_curve,
    upper_title="Family of curves {}".format(test_family_name),
    lower_title="Focus on end points. X, Y distances may be distorted."
)


# -*- coding: utf-8 -*-

from setuptools import setup

# read the contents of your README file
from os import path

this_directory = path.abspath(path.dirname(__file__))
with open(path.join(this_directory, "README.md"), encoding="utf-8") as f:
    long_description = f.read()

setup(
    name="arithmeticmeancurve",
    author="David Scheliga",
    author_email="david.scheliga@ivw.uni-kl.de",
    url="https://gitlab.com/david.scheliga/arithmeticmeancurve",
    project_urls={
        "Documentation": "https://arithmeticmeancurve.readthedocs.io/en/latest/",
        "Source Code Repository": "https://gitlab.com/david.scheliga/arithmeticmeancurve",
    },
    description="Module for calculating an arithmetic mean curve from a family of curves.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    license="GNU General Public License v3 (GPLv3)",
    classifiers=[
        # How mature is this project? Common values are
        #   3 - Alpha
        #   4 - Beta
        #   5 - Production/Stable
        "Development Status :: 3 - Alpha",
        # Pick your license as you wish (should match "license" above)
        "License :: OSI Approved :: GNU General Public License v3 (GPLv3)",
        "Operating System :: OS Independent",
        # Specify the Python versions you support here. In particular, ensure
        # that you indicate whether you support Python 2, Python 3 or both.
        "Programming Language :: Python :: 3",
    ],
    keywords="pandas, arithmetic, curve",
    py_modules=["arithmeticmeancurve"],
    python_requires=">=3.6",
    install_requires=["trashpanda>=0.8b0", "pandas", "numpy", "matplotlib", "scipy"],
    use_scm_version=True,
    setup_requires=['setuptools_scm'],
)



# Here examplecurves is used to get exemplary curves.
import examplecurves
curves = examplecurves.Static.create("nonlinear0")

# The actual calculation of the arithmetic mean curve.
from arithmeticmeancurve import ArithmeticMeanCurve
a_mean_curve = ArithmeticMeanCurve(curves=curves)

# Finally the plotting of the mean curve and the sample curves.
import matplotlib.pyplot as plt
plt.plot(a_mean_curve.mean_curve, "-ko", label="arithmetic mean curve")
for label, curve in a_mean_curve.family_of_curves.iteritems():
    plt.plot(curve, "-", label="label")
plt.plot(a_mean_curve.scatter_curve, "--k", label="scatter curve")
plt.plot(a_mean_curve.std_circle, "--r", label="std circle")
plt.legend()
plt.show()


from trashpanda import cut_after

import examplecurves
from arithmeticmeancurve import ArithmeticMeanCurve

sample_curves = examplecurves.Static.create(
    family_name="nonlinear0", predefined_offset=1
)
a_mean_curve = ArithmeticMeanCurve(sample_curves)
input_curves = a_mean_curve.family_of_curves.copy()
input_curves = cut_after(
    source_to_cut=input_curves, cutting_index=a_mean_curve.statistics.end_x_mean
)

standard_mean_curve = input_curves.mean(axis=1)


import matplotlib.pyplot as plt

# Setup figure
fig = plt.figure(figsize=(10, 5), dpi=96)
gspec = fig.add_gridspec(2, 5)
curve_axis = fig.add_subplot(gspec[:, :3])
mean_axis = fig.add_subplot(gspec[:, 3:])

curve_axis.set_title("Sample curves")
mean_axis.set_title("Mean curve without extrapolation")
# Plot
for index, curve in enumerate(sample_curves):
    current_label = "Sample curve {}".format(index)
    curve_axis.plot(curve, marker="o", markersize=3, label=current_label)

for index, (label, curve) in enumerate(a_mean_curve.family_of_curves.iteritems()):
    mean_axis.plot(curve, marker="o", markersize=3)
mean_axis.plot(standard_mean_curve, "--ko", markersize=3, label="Standard mean curve")

# Finishing touch
curve_axis.legend(loc="lower right")
mean_axis.legend(loc="lower right")
plt.tight_layout()
plt.show()



import examplecurves
from arithmeticmeancurve import FrozenStdExtrapolation, VisualIterationTester

sample_curves = examplecurves.Static.create(family_name="horizontallinear0")

# from arithmeticmeancurve import ArithmeticMeanCurve
#
# a_mean_curves =ArithmeticMeanCurve(sample_curves)
#
# import matplotlib.pyplot as plt
#
# plt.plot(a_mean_curves.family_of_curves, "-o")
# plt.ylim(bottom=9.4, top=10.1)
# plt.xlim(left=0.96, right=1.04)
# plt.plot(a_mean_curves.mean_curve, "-k")
# plt.legend()
# plt.show()


# print(a_mean_curves.mean_curve)

# VisualIterationTester.plot_extrapolation_test(
#     curves=sample_curves, extrapolates=FrozenStdExtrapolation(use_previous_iteration=False)
# )
